@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2017-2024, by Samuel Williams.
+# Copyright, 2017-2025, by Samuel Williams.
 # Copyright, 2022, by Ian Ker-Seymer.
 
 require "io/endpoint"
@@ -81,7 +81,7 @@ module Async
 			
 			def close
 				while @pool.busy?
-					Console.logger.warn(self) {"Waiting for #{@protocol} pool to drain: #{@pool}"}
+					Console.warn(self) {"Waiting for #{@protocol} pool to drain: #{@pool}"}
 					@pool.wait
 				end
 				
@@ -164,7 +164,7 @@ module Async
 				self.assign_default_tags(options[:tags] ||= {})
 				
 				Async::Pool::Controller.wrap(**options) do
-					Console.logger.debug(self) {"Making connection to #{@endpoint.inspect}"}
+					Console.debug(self) {"Making connection to #{@endpoint.inspect}"}
 					
 					@protocol.client(@endpoint.connect)
 				end
